@@ -3,10 +3,9 @@
 use std::iter::Sum;
 use std::ops::{Add, Deref, DerefMut};
 
-use ansiterm::{Style, ANSIString, ANSIStrings};
+use nu_ansi_term::{AnsiString as ANSIString, AnsiStrings as ANSIStrings, Style};
 use unicode_width::UnicodeWidthStr;
 
-
 /// An individual cell that holds text in a table, used in the details and
 /// lines views to store ANSI-terminal-formatted data before it is printed.
 ///
@@ -19,7 +18,6 @@ use unicode_width::UnicodeWidthStr;
 /// type by that name too.)
 #[derive(PartialEq, Debug, Clone, Default)]
 pub struct TextCell {
-
     /// The contents of this cell, as a vector of ANSI-styled strings.
     pub contents: TextCellContents,
 
@@ -36,14 +34,13 @@ impl Deref for TextCell {
 }
 
 impl TextCell {
-
     /// Creates a new text cell that holds the given text in the given style,
     /// computing the Unicode width of the text.
     pub fn paint(style: Style, text: String) -> Self {
         let width = DisplayWidth::from(&*text);
 
         Self {
-            contents: vec![ style.paint(text) ].into(),
+            contents: vec![style.paint(text)].into(),
             width,
         }
     }
@@ -55,7 +52,7 @@ impl TextCell {
         let width = DisplayWidth::from(text);
 
         Self {
-            contents: vec![ style.paint(text) ].into(),
+            contents: vec![style.paint(text)].into(),
             width,
         }
     }
@@ -68,8 +65,8 @@ impl TextCell {
     /// tabular data when there is *something* in each cell.
     pub fn blank(style: Style) -> Self {
         Self {
-            contents: vec![ style.paint("-") ].into(),
-            width:    DisplayWidth::from(1),
+            contents: vec![style.paint("-")].into(),
+            width: DisplayWidth::from(1),
         }
     }
 
@@ -96,7 +93,6 @@ impl TextCell {
     }
 }
 
-
 // I’d like to eventually abstract cells so that instead of *every* cell
 // storing a vector, only variable-length cells would, and individual cells
 // would just store an array of a fixed length (which would usually be just 1
@@ -123,7 +119,6 @@ impl TextCell {
 //
 // But exa still has bugs and I need to fix those first :(
 
-
 /// The contents of a text cell, as a vector of ANSI-styled strings.
 ///
 /// It’s possible to use this type directly in the case where you want a
@@ -152,7 +147,6 @@ impl Deref for TextCellContents {
 // above can just access the value directly.
 
 impl TextCellContents {
-
     /// Produces an `ANSIStrings` value that can be used to print the styled
     /// values of this cell as an ANSI-terminal-formatted string.
     pub fn strings(&self) -> ANSIStrings<'_> {
@@ -162,8 +156,9 @@ impl TextCellContents {
     /// Calculates the width that a cell with these contents would take up, by
     /// counting the number of characters in each unformatted ANSI string.
     pub fn width(&self) -> DisplayWidth {
-        self.0.iter()
-            .map(|anstr| DisplayWidth::from(&**anstr))
+        self.0
+            .iter()
+            .map(|anstr| DisplayWidth::from(anstr.as_str()))
             .sum()
     }
 
@@ -177,7 +172,6 @@ impl TextCellContents {
     }
 }
 
-
 /// The Unicode “display width” of a string.
 ///
 /// This is related to the number of *graphemes* of a string, rather than the
@@ -238,13 +232,13 @@ impl Add<usize> for DisplayWidth {
 
 impl Sum for DisplayWidth {
     fn sum<I>(iter: I) -> Self
-    where I: Iterator<Item = Self>
+    where
+        I: Iterator<Item = Self>,
     {
         iter.fold(Self(0), Add::add)
     }
 }
 
-
 #[cfg(test)]
 mod width_unit_test {
     use super::DisplayWidth;
